selenium_test_portlets
open | /ksstestportal |
open | ksstestportal/kssfolder/documentitem |
clickAt | css=h1#parent-fieldname-title |
waitForElementPresent | css=#archetypes-fieldname-title input |
type | css=#archetypes-fieldname-title input[value='KssDocument'] | KssDocumentRename
keyPress | css=h1#parent-fieldname-title input | \13
pause | 8000 |
waitForElementPresent | xpath=//a[text()="KssDocumentRename"] |
assertText | xpath=//a[text()="KssDocumentRename"] | KssDocumentRename
clickAt | css=h1#parent-fieldname-title |
waitForElementPresent | css=#archetypes-fieldname-title input |
type | css=#archetypes-fieldname-title input[value='KssDocumentRename'] | KssDocument
keyPress | css=h1#parent-fieldname-title input | \13
pause | 8000 |
waitForElementPresent | xpath=//a[text()="KssDocument"] |
assertText | xpath=//a[text()="KssDocument"] | KssDocument